diff lisp/startup.el @ 61505:c8cf56d85000

Added new X reosurce, cursorBlink.
author Jan Djärv <jan.h.d@swipnet.se>
date Tue, 12 Apr 2005 19:59:54 +0000
parents b9d559315c0a
children 7473921df065
line wrap: on
line diff
--- a/lisp/startup.el	Tue Apr 12 10:28:24 2005 +0000
+++ b/lisp/startup.el	Tue Apr 12 19:59:54 2005 +0000
@@ -714,10 +714,19 @@
     (and command-line-args
          (setcdr command-line-args args)))
 
   ;; Under X Windows, this creates the X frame and deletes the terminal frame.
   (when (fboundp 'frame-initialize)
     (frame-initialize))
 
+  ;; Turn off blinking cursor if so specified in X resources.  This is here
+  ;; only because all other settings of no-blinking-cursor is here.
+  (unless (or noninteractive
+	      emacs-basic-display
+	      (and (memq window-system '(x w32 mac))
+		   (not (member (x-get-resource "cursorBlink" "CursorBlink")
+				'("off" "false")))))
+    (setq no-blinking-cursor t))
+
   ;; If frame was created with a menu bar, set menu-bar-mode on.
   (unless (or noninteractive
 	      emacs-basic-display
@@ -714,10 +714,19 @@
          (setcdr command-line-args args)))
 
-  ;; Under X Windows, this creates the X frame and deletes the terminal frame.
+  ;; Under X Window, this creates the X frame and deletes the terminal frame.
   (when (fboundp 'frame-initialize)
     (frame-initialize))